#[non_exhaustive]pub enum PrecisionBehavior {
AutoTruncate,
Manual,
}Expand description
The behavior of a Displayable when a precision is set.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AutoTruncate
Automatically truncate the formatted text to the number of characters specified as the precision.
This is the behavior specified in std::fmt for non-numeric types.
Manual
The precision will be manually handled (or ignored) by
CustomDisplay::fmt() and CustomDisplay::width_in_chars().