display_non_numeric

Function display_non_numeric 

pub fn display_non_numeric<T>(
    value: &T,
) -> OwnedDisplayable<'_, DefaultNonNumeric<T>>
where T: Display + ?Sized,
Returns a wrapper around the given value that handles precision, width, fill and alignment in the way specified by std::fmt for non-numeric types.

For some type that implements Display, returns a wrapper that truncates the formatted value based on precision, pads it based on width, fill and alignment, and has a default Alignment of Left. This allows one to get the behavior specified by std::fmt for non-numeric types without having to implement the handling for precision, width, fill and alignment for their type. This method assumes all characters in the formatted value have a monospace width of 1.

See also default_non_numeric().