Displayable

Struct Displayable 

pub struct Displayable<'value, CD, B>
where CD: CustomDisplay + ?Sized, B: Borrow<CD>,
{ /* private fields */ }
A wrapper around a CustomDisplay and a value that implements Display by calling CustomDisplay::fmt() with the value, automatically truncates the result of CustomDisplay::fmt() based on precision if CustomDisplay::precision_behavior() returns AutoTruncate, and handles width, fill and alignment if CustomDisplay::auto_width_fill_alignment() returns true.