pub fn default_non_numeric<T>() -> DefaultNonNumeric<T>Expand description
Returns a CustomDisplay that provides handling of precision, width,
fill and alignment in the way specified by std::fmt for non-numeric
types.
For some type that implements Display, returns a CustomDisplay that,
when used by a Displayable, truncates the formatted value based on
precision, pads it based on width, fill and alignment, and has a
default Alignment of Left. This allows one to get the behavior
specified by std::fmt for non-numeric types without having to implement
the handling for precision, width, fill and alignment for their type.
The returned CustomDisplay assumes all characters in formatted values
have a monospace width of 1.
See also display_non_numeric().